/*
** uri.h - part of GrabURL 2.0
** Copyright (C) 1996-97 Serge Emond
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef GU_URI_H
#define GU_URI_H 1

struct URI {
  struct URI *next;
  struct URI *prev;
  char *uri;
  char *saveto;
  int flags;
  int depth;
};

struct URI_Head {
  struct URI *first;
  struct URI *last;
};

/* URI_MOVED ?? */

#define URI_RECEIVED		(1<<0)
#define URI_SKIP		(1<<1)
#define URI_FAILED		(1<<2)
#define URI_ERROR		(1<<3)
#define URI_MOVED		(1<<4)
#define URI_RETRY		(1<<5)
#define URI_SCAN		(1<<6)
#define URI_STAYINHOST		(1<<7)
#define URI_ADDHEAD		(1<<8)  /* Unimplemented */
#define URI_IFMODIFIED		(1<<9)
#define URI_NONEXISTS		(1<<10)
#define URI_SAVEHEAD		(1<<11)
#define URI_NODIRS		(1<<12)

#define URI_TYPES     (URI_RECEIVED | URI_SKIP | URI_FAILED | URI_ERROR | URI_MOVED)
#define URI_DEFAULTS  0

struct SURI {
  char *protocol;
  char *host;
  int port;
  char *path;
  char *filename;
  char *nuri;
};

extern struct URI_Head uri_list;

#define MAX_UFILE_LLEN  256		/* Max line len - no check done */

int AddURI(struct URI *, char *, int, int, const char *);
struct URI *FindURI(char *, int, int);
int CountURI(int, int);
int SaveURIFile(const char *);
int LoadURIFile(const char *);
char *MakeURILine(struct URI *);
int AddURILine(const char *);
struct SURI *SplitURI(const char *);

#define FreeSURI(suri) { if (suri) { free(suri->protocol); free(suri->host); \
                       free(suri->path); free(suri->filename); \
                       free(suri->nuri); free(suri); \
                       suri = (struct SURI *)0; } }

#endif
